@@ -12,7 +12,6 @@
 # limitations under the License.
 
 import os
-import subprocess
 import sys
 
 
@@ -53,15 +52,8 @@ source_suffix = '.rst'
 master_doc = 'index'
 
 # General information about the project.
-project = u'Workflow Service API Reference'
-copyright = u'2017, Mistral Contributors'
-
-# The version info for the project you're documenting, acts as replacement for
-# |version| and |release|, also used in various other places throughout the
-# built documents.
-from mistral.version import version_info
-release = version_info.release_string()
-version = version_info.version_string()
+project = 'Workflow Service API Reference'
+copyright = '2017, Mistral Contributors'
 
 # If true, sectionauthor and moduleauthor directives will be shown in the
 # output. They are ignored by default.
@@ -75,7 +67,7 @@ add_function_parentheses = True
 add_module_names = True
 
 # The name of the Pygments (syntax highlighting) style to use.
-pygments_style = 'sphinx'
+pygments_style = 'native'
 
 # -- Options for HTML output --------------------------------------------------
 
@@ -93,14 +85,6 @@ htmlhelp_basename = '%sdoc' % project
 # A list of ignored prefixes for module index sorting.
 modindex_common_prefix = ['mistral.']
 
-# If not '', a 'Last updated on:' timestamp is inserted at every page bottom,
-# using the given strftime format.
-# html_last_updated_fmt = '%b %d, %Y'
-git_cmd = ["git", "log", "--pretty=format:'%ad, commit %h'", "--date=local",
-           "-n1"]
-html_last_updated_fmt = subprocess.check_output(
-    git_cmd).decode('utf-8')
-
 # The name for this set of Sphinx documents. If None, it defaults to
 # "<project> v<release> documentation".
 html_title = 'Mistral API Reference'
@@ -122,8 +106,8 @@ html_sidebars = {
 # One entry per manual page. List of tuples
 # (source start file, name, description, authors, manual section).
 man_pages = [
-    ('index', 'mistral', u'Mistral',
-     [u'OpenStack Foundation'], 1)
+    ('index', 'mistral', 'Mistral',
+     ['OpenStack Foundation'], 1)
 ]
 
 # If true, show URL addresses after external links.
