@@ -15,6 +15,8 @@
 
 from oslo_config import cfg
 import oslo_middleware.cors as cors_middleware
+from oslo_middleware import healthcheck
+from oslo_middleware import http_proxy_to_wsgi
 import osprofiler.web
 import pecan
 
@@ -36,7 +38,8 @@ def get_pecan_config():
             "root": opts.root,
             "modules": opts.modules,
             "debug": opts.debug,
-            "auth_enable": opts.auth_enable
+            "auth_enable": opts.auth_enable,
+            "guess_content_type_from_ext": False,
         }
     }
 
@@ -53,14 +56,16 @@ def setup_app(config=None):
 
     db_api_v2.setup_db()
 
-    if not app_conf.pop('disable_cron_trigger_thread', False):
+    # TODO(rakhmerov): Why do we run cron triggers in the API layer?
+    # Should we move it to engine?s
+    if cfg.CONF.cron_trigger.enabled:
         periodic.setup()
 
     coordination.Service('api_group').register_membership()
 
     app = pecan.make_app(
         app_conf.pop('root'),
-        hooks=lambda: [ctx.ContextHook(), ctx.AuthHook()],
+        hooks=lambda: [ctx.AuthHook(), ctx.ContextHook()],
         logging=getattr(config, 'logging', {}),
         **app_conf
     )
@@ -80,6 +85,13 @@ def setup_app(config=None):
             enabled=cfg.CONF.profiler.enabled
         )
 
+    # Create HTTPProxyToWSGI wrapper
+    app = http_proxy_to_wsgi.HTTPProxyToWSGI(app, cfg.CONF)
+
+    # Create a healthcheck wrapper
+    if cfg.CONF.healthcheck.enabled:
+        app = healthcheck.Healthcheck(app, cfg.CONF)
+
     # Create a CORS wrapper, and attach mistral-specific defaults that must be
     # included in all CORS responses.
     return cors_middleware.CORS(app, cfg.CONF)
