@@ -570,6 +570,30 @@ action_logging_opts = [
     )
 ]
 
+context_versioning_opts = [
+    cfg.BoolOpt(
+        'enabled',
+        default=True,
+        help=(
+            'If this value is set to True then Mistral will use '
+            'versioning of context to improve results of context '
+            'merging. This feature fixes some bugs with context merging '
+            'but also slows down Mistral performance.'
+        )
+    ),
+    cfg.BoolOpt(
+        'hash_version_keys',
+        default=True,
+        help=(
+            'If this value is set to True then Mistral will use '
+            'md5 hashing for version keys to ensure this keys will be '
+            'the same size. Disabling hashing could be useful for debug '
+            'purposes, but avoid this in production, because it leads to '
+            'excessive memory consumption.'
+        )
+    )
+]
+
 coordination_opts = [
     cfg.StrOpt(
         'backend_url',
@@ -579,6 +603,8 @@ coordination_opts = [
     cfg.FloatOpt(
         'heartbeat_interval',
         default=5.0,
+        deprecated_for_removal=True,
+        deprecated_reason='This option has been unused and has had no effect',
         help=_('Number of seconds between heartbeats for coordination.')
     )
 ]
@@ -718,6 +744,17 @@ yaql_opts = [
     )
 ]
 
+
+healthcheck_opts = [
+    cfg.BoolOpt('enabled',
+                default=False,
+                help=_('Enable the health check endpoint at /healthcheck. '
+                       'Note that this is unauthenticated. More information '
+                       'is available at '
+                       'https://docs.openstack.org/oslo.middleware/latest/'
+                       'reference/healthcheck_plugins.html.')),
+]
+
 CONF = cfg.CONF
 
 LEGACY_ACTION_PROVIDER_GROUP = 'legacy_action_provider'
@@ -733,9 +770,11 @@ COORDINATION_GROUP = 'coordination'
 EXECUTION_EXPIRATION_POLICY_GROUP = 'execution_expiration_policy'
 ACTION_HEARTBEAT_GROUP = 'action_heartbeat'
 ACTION_LOGGING_GROUP = 'action_logging'
+CONTEXT_VERSIONING_GROUP = 'context_versioning'
 PROFILER_GROUP = profiler.list_opts()[0][0]
 KEYCLOAK_OIDC_GROUP = "keycloak_oidc"
 YAQL_GROUP = "yaql"
+HEALTHCHECK_GROUP = 'healthcheck'
 KEYSTONE_GROUP = "keystone"
 
 
@@ -766,6 +805,7 @@ CONF.register_opts(
     group=ACTION_HEARTBEAT_GROUP
 )
 CONF.register_opts(action_logging_opts, group=ACTION_LOGGING_GROUP)
+CONF.register_opts(context_versioning_opts, group=CONTEXT_VERSIONING_GROUP)
 CONF.register_opts(event_engine_opts, group=EVENT_ENGINE_GROUP)
 CONF.register_opts(notifier_opts, group=NOTIFIER_GROUP)
 CONF.register_opts(pecan_opts, group=PECAN_GROUP)
@@ -773,6 +813,7 @@ CONF.register_opts(coordination_opts, group=COORDINATION_GROUP)
 CONF.register_opts(profiler_opts, group=PROFILER_GROUP)
 CONF.register_opts(keycloak_oidc_opts, group=KEYCLOAK_OIDC_GROUP)
 CONF.register_opts(yaql_opts, group=YAQL_GROUP)
+CONF.register_opts(healthcheck_opts, group=HEALTHCHECK_GROUP)
 loading.register_session_conf_options(CONF, KEYSTONE_GROUP)
 
 CLI_OPTS = [
@@ -820,8 +861,10 @@ def list_opts():
         (PROFILER_GROUP, profiler_opts),
         (KEYCLOAK_OIDC_GROUP, keycloak_oidc_opts),
         (YAQL_GROUP, yaql_opts),
+        (HEALTHCHECK_GROUP, healthcheck_opts),
         (ACTION_HEARTBEAT_GROUP, action_heartbeat_opts),
         (ACTION_LOGGING_GROUP, action_logging_opts),
+        (CONTEXT_VERSIONING_GROUP, context_versioning_opts),
         (None, default_group_opts)
     ]
 
