@@ -129,6 +129,7 @@ class Definition(mb.MistralSecureModelBase):
 
     id = mb.id_column()
     name = sa.Column(sa.String(255))
+    namespace = sa.Column(sa.String(255), nullable=True)
     definition = sa.Column(st.MediumText(), nullable=True)
     spec = sa.Column(st.JsonMediumDictType())
     tags = sa.Column(st.JsonListType())
@@ -140,8 +141,6 @@ class Workbook(Definition):
     """Contains info about workbook (including definition in Mistral DSL)."""
 
     __tablename__ = 'workbooks_v2'
-    namespace = sa.Column(sa.String(255), nullable=True)
-
     __table_args__ = (
         sa.UniqueConstraint(
             'name',
@@ -157,7 +156,7 @@ class WorkflowDefinition(Definition):
     """Contains info about workflow (including definition in Mistral DSL)."""
 
     __tablename__ = 'workflow_definitions_v2'
-    namespace = sa.Column(sa.String(255), nullable=True)
+    checksum = sa.Column(sa.String(32), nullable=True)
     __table_args__ = (
         sa.UniqueConstraint(
             'name',
@@ -169,12 +168,13 @@ class WorkflowDefinition(Definition):
         sa.Index('%s_scope' % __tablename__, 'scope'),
     )
 
+    workbook_name = sa.Column(sa.String(255))
+
 
 class ActionDefinition(Definition):
     """Contains info about registered Actions."""
 
     __tablename__ = 'action_definitions_v2'
-    namespace = sa.Column(sa.String(255), nullable=True)
     __table_args__ = (
         sa.UniqueConstraint(
             'name',
@@ -186,6 +186,8 @@ class ActionDefinition(Definition):
         sa.Index('%s_scope' % __tablename__, 'scope'),
     )
 
+    workbook_name = sa.Column(sa.String(255))
+
     # Main properties.
     description = sa.Column(sa.Text())
     input = sa.Column(sa.Text())
@@ -195,6 +197,64 @@ class ActionDefinition(Definition):
     attributes = sa.Column(st.JsonDictType())
 
 
+class CodeSource(mb.MistralSecureModelBase):
+    """Contains info about registered CodeSources."""
+
+    __tablename__ = 'code_sources'
+    __table_args__ = (
+        sa.UniqueConstraint(
+            'name',
+            'namespace',
+            'project_id'
+        ),
+        sa.Index('%s_project_id' % __tablename__, 'project_id'),
+        sa.Index('%s_scope' % __tablename__, 'scope'),
+    )
+
+    # Main properties.
+    id = mb.id_column()
+    name = sa.Column(sa.String(255))
+    content = sa.Column(sa.Text())
+    version = sa.Column(sa.Integer())
+    namespace = sa.Column(sa.String(255), nullable=True)
+    tags = sa.Column(st.JsonListType())
+
+
+class DynamicActionDefinition(mb.MistralSecureModelBase):
+    """Contains info about registered Dynamic Actions."""
+
+    __tablename__ = 'dynamic_action_definitions'
+    __table_args__ = (
+        sa.UniqueConstraint(
+            'name',
+            'namespace',
+            'project_id'
+        ),
+        sa.Index('%s_project_id' % __tablename__, 'project_id'),
+        sa.Index('%s_scope' % __tablename__, 'scope'),
+    )
+
+    # Main properties.
+    id = mb.id_column()
+    name = sa.Column(sa.String(255))
+    namespace = sa.Column(sa.String(255), nullable=True)
+    class_name = sa.Column(sa.String(255))
+    code_source_name = sa.Column(sa.String(255))
+
+
+DynamicActionDefinition.code_source_id = sa.Column(
+    sa.String(36),
+    sa.ForeignKey(CodeSource.id, ondelete='CASCADE'),
+    nullable=False
+)
+
+DynamicActionDefinition.code_source = relationship(
+    CodeSource,
+    remote_side=CodeSource.id,
+    lazy='select'
+)
+
+
 # Execution objects.
 
 class Execution(mb.MistralSecureModelBase):
