@@ -167,6 +167,26 @@ class EngineServer(service_base.MistralService):
             **params
         )
 
+    def start_task(self, rpc_ctx, task_ex_id, first_run, waiting,
+                   triggered_by, rerun, **params):
+        """Receives calls over RPC to start tasks on engine.
+
+        """
+        LOG.info(
+            "Received RPC request 'start_task'[task_ex_id=%s, first_run=%s]",
+            task_ex_id,
+            first_run
+        )
+
+        return self.engine.start_task(
+            task_ex_id,
+            first_run,
+            waiting,
+            triggered_by,
+            rerun,
+            **params
+        )
+
     def start_action(self, rpc_ctx, action_name,
                      action_input, description, namespace, params):
         """Receives calls over RPC to start actions on engine.
@@ -246,12 +266,15 @@ class EngineServer(service_base.MistralService):
 
         return self.engine.pause_workflow(wf_ex_id)
 
-    def rerun_workflow(self, rpc_ctx, task_ex_id, reset=True, env=None):
+    def rerun_workflow(self, rpc_ctx, task_ex_id, reset=True,
+                       skip=False, env=None):
         """Receives calls over RPC to rerun workflows on engine.
 
         :param rpc_ctx: RPC request context.
         :param task_ex_id: Task execution id.
         :param reset: If true, then purge action execution for the task.
+        :param skip: If True, then skip failed task and continue workflow
+            execution.
         :param env: Environment variables to update.
         :return: Workflow execution.
         """
@@ -260,7 +283,7 @@ class EngineServer(service_base.MistralService):
             task_ex_id
         )
 
-        return self.engine.rerun_workflow(task_ex_id, reset, env)
+        return self.engine.rerun_workflow(task_ex_id, reset, skip, env)
 
     def resume_workflow(self, rpc_ctx, wf_ex_id, env=None):
         """Receives calls over RPC to resume workflows on engine.
