@@ -23,22 +23,23 @@ class PoliciesSpec(base.BaseSpec):
     _schema = {
         "type": "object",
         "properties": {
-            "retry": types.ANY,
+            "retry": retry_policy.RetrySpec.get_schema(),
             "wait-before": types.EXPRESSION_OR_POSITIVE_INTEGER,
             "wait-after": types.EXPRESSION_OR_POSITIVE_INTEGER,
             "timeout": types.EXPRESSION_OR_POSITIVE_INTEGER,
             "pause-before": types.EXPRESSION_OR_BOOLEAN,
             "concurrency": types.EXPRESSION_OR_POSITIVE_INTEGER,
+            "fail-on": types.EXPRESSION_OR_BOOLEAN
         },
         "additionalProperties": False
     }
 
     @classmethod
-    def get_schema(cls, includes=['definitions']):
+    def get_schema(cls, includes=('definitions',)):
         return super(PoliciesSpec, cls).get_schema(includes)
 
-    def __init__(self, data):
-        super(PoliciesSpec, self).__init__(data)
+    def __init__(self, data, validate):
+        super(PoliciesSpec, self).__init__(data, validate)
 
         self._retry = self._spec_property('retry', retry_policy.RetrySpec)
         self._wait_before = data.get('wait-before', 0)
@@ -46,6 +47,7 @@ class PoliciesSpec(base.BaseSpec):
         self._timeout = data.get('timeout', 0)
         self._pause_before = data.get('pause-before', False)
         self._concurrency = data.get('concurrency', 0)
+        self._fail_on = data.get('fail-on', False)
 
     def validate_schema(self):
         super(PoliciesSpec, self).validate_schema()
@@ -56,6 +58,7 @@ class PoliciesSpec(base.BaseSpec):
         self.validate_expr(self._data.get('timeout', 0))
         self.validate_expr(self._data.get('pause-before', False))
         self.validate_expr(self._data.get('concurrency', 0))
+        self.validate_expr(self._data.get('fail-on', False))
 
     def get_retry(self):
         return self._retry
@@ -74,3 +77,6 @@ class PoliciesSpec(base.BaseSpec):
 
     def get_concurrency(self):
         return self._concurrency
+
+    def get_fail_on(self):
+        return self._fail_on
