@@ -15,10 +15,11 @@
 
 import itertools
 from kombu.mixins import ConsumerMixin
-import six
+import queue
 import threading
 
 from oslo_log import log as logging
+from oslo_utils import eventletutils
 
 from mistral.rpc.kombu import base as kombu_base
 
@@ -32,12 +33,12 @@ class KombuRPCListener(ConsumerMixin):
         self._connections = itertools.cycle(connections)
         self._callback_queue = callback_queue
         self._thread = None
-        self.connection = six.next(self._connections)
+        self.connection = next(self._connections)
 
-        self.ready = threading.Event()
+        self.ready = eventletutils.Event()
 
     def add_listener(self, correlation_id):
-        self._results[correlation_id] = six.moves.queue.Queue()
+        self._results[correlation_id] = queue.Queue()
 
     def remove_listener(self, correlation_id):
         if correlation_id in self._results:
@@ -71,7 +72,7 @@ class KombuRPCListener(ConsumerMixin):
         :param message: the plain amqp kombu.message with additional
             information
         """
-        LOG.debug("Got response: {0}".format(response))
+        LOG.debug("Got response: {}", response)
 
         try:
             message.ack()
@@ -95,8 +96,8 @@ class KombuRPCListener(ConsumerMixin):
                 queue.put(result)
             else:
                 LOG.debug(
-                    "Got a response, but seems like no process is waiting for"
-                    "it [correlation_id={0}]".format(correlation_id)
+                    "Got a response, but seems like no process is waiting for "
+                    "it [correlation_id={}]", correlation_id
                 )
 
     def get_result(self, correlation_id, timeout):
@@ -105,7 +106,7 @@ class KombuRPCListener(ConsumerMixin):
     def on_connection_error(self, exc, interval):
         self.ready.clear()
 
-        self.connection = six.next(self._connections)
+        self.connection = next(self._connections)
 
         LOG.debug("Broker connection failed: %s", exc)
         LOG.debug(
