@@ -18,6 +18,7 @@ import eventlet
 from mistral import context as auth_ctx
 from mistral.db import utils as db_utils
 from mistral.db.v2 import api as db_api
+from mistral.db.v2.sqlalchemy import models as db_models
 from mistral.engine import action_handler
 from mistral.engine import post_tx_queue
 from mistral_lib import actions as mistral_lib
@@ -50,21 +51,39 @@ def handle_expired_actions():
             CONF.action_heartbeat.batch_size
         )
 
-        LOG.debug("Found {} running and expired actions.".format(
-            len(action_exs))
-        )
+        LOG.debug("Found {} running and expired actions.", len(action_exs))
 
         if action_exs:
             LOG.info(
                 "Actions executions to transit to error, because "
-                "heartbeat wasn't received: {}".format(action_exs)
+                "heartbeat wasn't received: {}", action_exs
             )
 
             for action_ex in action_exs:
+                task_ex = db_api.get_task_execution(
+                    action_ex.task_execution_id
+                )
+                wf_ex = db_api.get_workflow_execution(
+                    task_ex.workflow_execution_id,
+                    fields=(db_models.WorkflowExecution.id,
+                            db_models.WorkflowExecution.root_execution_id)
+                )
+
+                if wf_ex.root_execution_id:
+                    root_execution_id = wf_ex.root_execution_id
+                else:
+                    root_execution_id = wf_ex.id
+
                 result = mistral_lib.Result(
                     error="Heartbeat wasn't received."
                 )
 
+                auth_ctx.set_ctx(
+                    auth_ctx.MistralContext(
+                        root_execution_id=root_execution_id
+                    )
+                )
+
                 action_handler.on_action_complete(action_ex, result)
 
 
@@ -110,7 +129,7 @@ def start():
     LOG.debug(
         "First run of action heartbeat checker, wait before "
         "checking to make sure executors have time to send "
-        "heartbeats. ({} seconds)".format(wait_time)
+        "heartbeats. ({} seconds)", wait_time
     )
 
     global _stopped
