@@ -16,18 +16,20 @@
 import copy
 import datetime
 import json
+from unittest import mock
 
-import mock
 from oslo_config import cfg
 import oslo_messaging
+from oslo_messaging import exceptions as oslo_exc
 import sqlalchemy as sa
 
 from mistral.api.controllers.v2 import action_execution
+from mistral.api.controllers.v2 import resources
 from mistral.db.v2 import api as db_api
 from mistral.db.v2.sqlalchemy import models
 from mistral import exceptions as exc
-from mistral.rpc import base as rpc_base
 from mistral.rpc import clients as rpc_clients
+from mistral.rpc.oslo import oslo_client
 from mistral.tests.unit.api import base
 from mistral.utils import rest_utils
 from mistral.workflow import states
@@ -206,8 +208,10 @@ MOCK_EMPTY = mock.MagicMock(return_value=[])
 MOCK_NOT_FOUND = mock.MagicMock(side_effect=exc.DBEntityNotFoundError())
 MOCK_DELETE = mock.MagicMock(return_value=None)
 
+ACTION_EX_DB_WITH_PROJECT_ID = AD_HOC_ACTION_EX_DB.get_clone()
+ACTION_EX_DB_WITH_PROJECT_ID.project_id = '<default-project>'
+
 
-@mock.patch.object(rpc_base, '_IMPL_CLIENT', mock.Mock())
 class TestActionExecutionsController(base.APITest):
     def setUp(self):
         super(TestActionExecutionsController, self).setUp()
@@ -222,9 +226,22 @@ class TestActionExecutionsController(base.APITest):
     @mock.patch.object(db_api, 'get_action_execution', MOCK_ACTION)
     def test_get(self):
         resp = self.app.get('/v2/action_executions/123')
+        action_exec = copy.deepcopy(ACTION_EX)
+        del action_exec['task_name']
+        self.assertEqual(200, resp.status_int)
+        self.assertDictEqual(action_exec, resp.json)
+
+    @mock.patch('mistral.db.v2.api.get_action_execution')
+    def test_get_with_fields_filter(self, mocked_get):
+        mocked_get.return_value = (ACTION_EX['id'], ACTION_EX['name'],)
+        resp = self.app.get('/v2/action_executions/123?fields=name')
+        expected = {
+            'id': ACTION_EX['id'],
+            'name': ACTION_EX['name'],
+        }
 
         self.assertEqual(200, resp.status_int)
-        self.assertDictEqual(ACTION_EX, resp.json)
+        self.assertDictEqual(expected, resp.json)
 
     @mock.patch.object(db_api, 'get_action_execution')
     def test_get_operational_error(self, mocked_get):
@@ -235,9 +252,10 @@ class TestActionExecutionsController(base.APITest):
         ]
 
         resp = self.app.get('/v2/action_executions/123')
-
+        action_exec = copy.deepcopy(ACTION_EX)
+        del action_exec['task_name']
         self.assertEqual(200, resp.status_int)
-        self.assertDictEqual(ACTION_EX, resp.json)
+        self.assertDictEqual(action_exec, resp.json)
 
     def test_basic_get(self):
         resp = self.app.get('/v2/action_executions/')
@@ -249,6 +267,33 @@ class TestActionExecutionsController(base.APITest):
 
         self.assertEqual(404, resp.status_int)
 
+    @mock.patch.object(db_api, 'get_action_execution',
+                       return_value=ACTION_EX_DB_WITH_PROJECT_ID)
+    def test_get_within_project_id(self, mock_get):
+        resp = self.app.get('/v2/action_executions/123')
+
+        self.assertEqual(200, resp.status_int)
+        self.assertIn('project_id', resp.json)
+
+    @mock.patch.object(oslo_client.OsloRPCClient, 'sync_call',
+                       mock.MagicMock(side_effect=oslo_exc.MessagingTimeout))
+    def test_post_timeout(self):
+        self.override_config('rpc_response_timeout', 100)
+
+        resp = self.app.post_json(
+            '/v2/action_executions',
+            {
+                'name': 'std.sleep',
+                'input': {'seconds': 120}
+            },
+            expect_errors=True
+        )
+
+        error_msg = resp.json['faultstring']
+        self.assertEqual(error_msg,
+                         'This rpc call "start_action" took longer than '
+                         'configured 100 seconds.')
+
     @mock.patch.object(rpc_clients.EngineClient, 'start_action')
     def test_post(self, f):
         f.return_value = ACTION_EX_DB.to_dict()
@@ -274,7 +319,36 @@ class TestActionExecutionsController(base.APITest):
             json.loads(action_exec['input']),
             description=None,
             save_result=True,
-            run_sync=True
+            run_sync=True,
+            namespace=''
+        )
+
+    @mock.patch.object(rpc_clients.EngineClient, 'start_action')
+    def test_post_with_timeout(self, f):
+        f.return_value = ACTION_EX_DB.to_dict()
+
+        resp = self.app.post_json(
+            '/v2/action_executions',
+            {
+                'name': 'std.echo',
+                'input': "{}",
+                'params': '{"timeout": 2}'
+            }
+        )
+
+        self.assertEqual(201, resp.status_int)
+
+        action_exec = copy.deepcopy(ACTION_EX)
+        del action_exec['task_name']
+
+        self.assertDictEqual(action_exec, resp.json)
+
+        f.assert_called_once_with(
+            action_exec['name'],
+            json.loads(action_exec['input']),
+            description=None,
+            timeout=2,
+            namespace=''
         )
 
     @mock.patch.object(rpc_clients.EngineClient, 'start_action')
@@ -301,7 +375,8 @@ class TestActionExecutionsController(base.APITest):
             action_exec['name'],
             json.loads(action_exec['input']),
             description=None,
-            save_result=True
+            save_result=True,
+            namespace=''
         )
 
     @mock.patch.object(rpc_clients.EngineClient, 'start_action')
@@ -317,7 +392,9 @@ class TestActionExecutionsController(base.APITest):
         self.assertEqual(201, resp.status_int)
         self.assertEqual('{"result": "123"}', resp.json['output'])
 
-        f.assert_called_once_with('nova.servers_list', {}, description=None)
+        f.assert_called_once_with('nova.servers_list', {},
+                                  description=None,
+                                  namespace='')
 
     def test_post_bad_result(self):
         resp = self.app.post_json(
@@ -498,11 +575,12 @@ class TestActionExecutionsController(base.APITest):
     @mock.patch.object(db_api, 'get_action_executions', MOCK_ACTIONS)
     def test_get_all(self):
         resp = self.app.get('/v2/action_executions')
-
+        action_exec = copy.deepcopy(ACTION_EX)
+        del action_exec['task_name']
         self.assertEqual(200, resp.status_int)
 
         self.assertEqual(1, len(resp.json['action_executions']))
-        self.assertDictEqual(ACTION_EX, resp.json['action_executions'][0])
+        self.assertDictEqual(action_exec, resp.json['action_executions'][0])
 
     @mock.patch.object(db_api, 'get_action_executions')
     def test_get_all_operational_error(self, mocked_get_all):
@@ -513,16 +591,19 @@ class TestActionExecutionsController(base.APITest):
         ]
 
         resp = self.app.get('/v2/action_executions')
+        action_exec = copy.deepcopy(ACTION_EX)
+        del action_exec['task_name']
 
         self.assertEqual(200, resp.status_int)
 
         self.assertEqual(1, len(resp.json['action_executions']))
-        self.assertDictEqual(ACTION_EX, resp.json['action_executions'][0])
+        self.assertDictEqual(action_exec, resp.json['action_executions'][0])
 
-    @mock.patch.object(db_api, 'get_action_executions', MOCK_ACTIONS)
-    @mock.patch.object(rest_utils, 'get_all')
-    def test_get_all_with_and_without_output(self, mock_get_all):
+    @mock.patch.object(rest_utils, 'get_all',
+                       return_value=resources.ActionExecutions())
+    def test_get_all_without_output(self, mock_get_all):
         resp = self.app.get('/v2/action_executions')
+
         args, kwargs = mock_get_all.call_args
         resource_function = kwargs['resource_function']
 
@@ -532,7 +613,11 @@ class TestActionExecutionsController(base.APITest):
             resource_function
         )
 
+    @mock.patch.object(rest_utils, 'get_all',
+                       return_value=resources.ActionExecutions())
+    def test_get_all_with_output(self, mock_get_all):
         resp = self.app.get('/v2/action_executions?include_output=true')
+
         args, kwargs = mock_get_all.call_args
         resource_function = kwargs['resource_function']
 
