@@ -17,7 +17,6 @@ import datetime
 import json
 from unittest import mock
 
-import six
 import sqlalchemy as sa
 
 from mistral.api.controllers.v2 import resources
@@ -120,7 +119,7 @@ MOCK_DELETE = mock.MagicMock(return_value=None)
 def _convert_vars_to_dict(env_dict):
     """Converts 'variables' in the given environment dict into dictionary."""
     if ('variables' in env_dict and
-            isinstance(env_dict.get('variables'), six.string_types)):
+            isinstance(env_dict.get('variables'), str)):
         env_dict['variables'] = json.loads(env_dict['variables'])
 
     return env_dict
@@ -189,6 +188,20 @@ class TestEnvironmentController(base.APITest):
         self.assertEqual(200, resp.status_int)
         self._assert_dict_equal(ENVIRONMENT, resp.json)
 
+    @mock.patch('mistral.db.v2.api.get_environment')
+    def test_get_with_fields_filter(self, mocked_get):
+        mocked_get.return_value = (
+            ENVIRONMENT['id'], ENVIRONMENT['name'],
+        )
+        resp = self.app.get('/v2/environments/123?fields=name')
+        expected = {
+            'id': ENVIRONMENT['id'],
+            'name': ENVIRONMENT['name'],
+        }
+
+        self.assertEqual(200, resp.status_int)
+        self.assertDictEqual(expected, resp.json)
+
     @mock.patch.object(db_api, 'get_environment')
     def test_get_operational_error(self, mocked_get):
         mocked_get.side_effect = [
