@@ -28,10 +28,10 @@ from mistral.executors import executor_server
 from mistral.notifiers import notification_server as notif_server
 from mistral.rpc import base as rpc_base
 from mistral.rpc import clients as rpc_clients
+from mistral.services import actions as action_service
 from mistral.tests.unit import base
 from mistral.workflow import states
 
-
 LOG = logging.getLogger(__name__)
 
 # Default delay and timeout in seconds for await_xxx() functions.
@@ -51,6 +51,12 @@ class EngineTestCase(base.DbTestCase):
     def setUp(self):
         super(EngineTestCase, self).setUp()
 
+        # We assume that most tests don't need a remote executor.
+        # But this option can be overridden on a test level, if needed,
+        # because an executor instance (local or a client to a remote one)
+        # is obtained by engine dynamically on every need.
+        self.override_config('type', 'local', 'executor')
+
         # Get transport here to let oslo.messaging setup default config
         # before changing the rpc_backend to the fake driver; otherwise,
         # oslo.messaging will throw exception.
@@ -75,8 +81,12 @@ class EngineTestCase(base.DbTestCase):
             exe_svc = executor_server.get_oslo_service(setup_profiler=False)
 
             self.executor = exe_svc.executor
+
             self.threads.append(eventlet.spawn(launch_service, exe_svc))
+
             self.addCleanup(exe_svc.stop, True)
+        else:
+            self.executor = exe.get_executor(cfg.CONF.executor.type)
 
         # Start remote notifier.
         if cfg.CONF.notifier.type == 'remote':
@@ -104,6 +114,10 @@ class EngineTestCase(base.DbTestCase):
         self.addOnException(self.print_executions)
         self.addCleanup(self.kill_threads)
 
+        # This call ensures that all plugged in action providers are
+        # properly initialized.
+        action_service.get_system_action_provider()
+
         # Make sure that both services fully started, otherwise
         # the test may run too early.
         if cfg.CONF.executor.type == 'remote':
@@ -185,6 +199,11 @@ class EngineTestCase(base.DbTestCase):
     def is_action_in_state(self, ex_id, state):
         return db_api.get_action_execution(ex_id).state == state
 
+    def is_action_created(self, task_ex_id):
+        return bool(db_api.get_action_executions(
+            task_execution_id=task_ex_id
+        ))
+
     def await_action_state(self, ex_id, state, delay=DEFAULT_DELAY,
                            timeout=DEFAULT_TIMEOUT):
         self._await(
@@ -260,6 +279,14 @@ class EngineTestCase(base.DbTestCase):
                              timeout=DEFAULT_TIMEOUT):
         self._await(lambda: self.is_task_processed(ex_id), delay, timeout)
 
+    def await_task_creates_action(self, ex_id, delay=DEFAULT_DELAY,
+                                  timeout=DEFAULT_TIMEOUT):
+        self._await(
+            lambda: self.is_action_created(ex_id),
+            delay,
+            timeout
+        )
+
     # Various methods for workflow execution objects.
 
     def is_workflow_in_state(self, ex_id, state):
