@@ -1,5 +1,6 @@
 # Copyright 2014 - Mirantis, Inc.
 # Copyright 2015 - StackStorm, Inc.
+# Copyright 2020 Nokia Software.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,8 +14,6 @@
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
 
-import six
-
 from oslo_config import cfg
 
 from mistral.db.v2 import api as db_api
@@ -33,6 +32,10 @@ cfg.CONF.set_default('auth_enable', False, group='pecan')
 
 
 class DirectWorkflowEngineTest(base.EngineTestCase):
+    def setUp(self):
+        super(DirectWorkflowEngineTest, self).setUp()
+        self.override_config('hash_version_keys', False, 'context_versioning')
+
     def _run_workflow(self, wf_text, expected_state=states.ERROR):
         wf_service.create_workflows(wf_text)
 
@@ -283,9 +286,11 @@ class DirectWorkflowEngineTest(base.EngineTestCase):
         wf_service.create_workflows(wf_text)
 
         wf_ex = self.engine.start_workflow('wf')
-
+        self.await_workflow_error(wf_ex.id)
+        with db_api.transaction():
+            wf_ex = db_api.get_workflow_execution(wf_ex.id)
         self.assertIn(
-            "Failed to find action [action_name=wrong.task]",
+            "Failed to find action [action_name=wrong.task, namespace=]",
             wf_ex.state_info
         )
         self.assertEqual(states.ERROR, wf_ex.state)
@@ -373,13 +378,11 @@ class DirectWorkflowEngineTest(base.EngineTestCase):
             wf_ex = db_api.get_workflow_execution(wf_ex.id)
 
             task_execs = wf_ex.task_executions
+            task_1_ex = self._assert_single_item(task_execs, name='task1')
 
         self.assertEqual(states.RUNNING, wf_ex.state)
         self.assertEqual(1, len(task_execs))
-
-        task_1_ex = self._assert_single_item(task_execs, name='task1')
-
-        self.assertEqual(states.RUNNING, task_1_ex.state)
+        self.await_task_running(task_1_ex.id)
 
         task_1_action_exs = db_api.get_action_executions(
             task_execution_id=task_1_ex.id
@@ -394,6 +397,13 @@ class DirectWorkflowEngineTest(base.EngineTestCase):
             ml_actions.Result(data='foobar')
         )
 
+        with db_api.transaction():
+            wf_ex = db_api.get_workflow_execution(wf_ex.id)
+
+            task_execs = wf_ex.task_executions
+            task_2_ex = self._assert_single_item(task_execs, name='task2')
+        self.await_task_error(task_2_ex.id)
+
         with db_api.transaction():
             wf_ex = db_api.get_workflow_execution(wf_ex.id)
 
@@ -547,6 +557,9 @@ class DirectWorkflowEngineTest(base.EngineTestCase):
         wf_service.create_workflows(wf_text)
 
         wf_ex = self.engine.start_workflow('wf')
+        self.await_workflow_error(wf_ex.id)
+        with db_api.transaction():
+            wf_ex = db_api.get_workflow_execution(wf_ex.id)
 
         self.assertIn(
             "Can not evaluate YAQL expression [expression=wrong(yaql)",
@@ -570,6 +583,9 @@ class DirectWorkflowEngineTest(base.EngineTestCase):
         wf_service.create_workflows(wf_text)
 
         wf_ex = self.engine.start_workflow('wf', wf_input={'var': 2})
+        self.await_workflow_error(wf_ex.id)
+        with db_api.transaction():
+            wf_ex = db_api.get_workflow_execution(wf_ex.id)
 
         self.assertIn("Can not evaluate YAQL expression", wf_ex.state_info)
         self.assertEqual(states.ERROR, wf_ex.state)
@@ -677,10 +693,12 @@ class DirectWorkflowEngineTest(base.EngineTestCase):
             wf_ex = db_api.get_workflow_execution(wf_ex.id)
 
             task_execs = wf_ex.task_executions
+            task_1_ex = self._assert_single_item(task_execs, name='task1')
 
+        self.await_task_running(task_1_ex.id)
         self.assertEqual(1, len(task_execs))
 
-        task_1_ex = self._assert_single_item(task_execs, name='task1')
+        task_1_ex = db_api.get_task_execution(task_1_ex.id)
 
         self.assertEqual(states.RUNNING, task_1_ex.state)
 
@@ -975,19 +993,47 @@ class DirectWorkflowEngineTest(base.EngineTestCase):
         task2_2_ex = self._assert_single_item(tasks_execs, name='task2_2')
 
         self.assertDictEqual({}, task0_ex.in_context)
-        self.assertDictEqual({'var0': 'val0'}, task1_1_ex.in_context)
         self.assertDictEqual(
             {
                 'var0': 'val0',
-                'var1': 'val1'
+                '__versions':
+                {
+                    'var0': 1
+                }
+            },
+            task1_1_ex.in_context
+        )
+        self.assertDictEqual(
+            {
+                'var0': 'val0',
+                'var1': 'val1',
+                '__versions':
+                {
+                    'var0': 1,
+                    'var1': 1
+                }
             },
             task1_2_ex.in_context
         )
-        self.assertDictEqual({'var0': 'val0'}, task2_1_ex.in_context)
         self.assertDictEqual(
             {
                 'var0': 'val0',
-                'var2': 'val2'
+                '__versions':
+                {
+                    'var0': 1
+                }
+            },
+            task2_1_ex.in_context
+        )
+        self.assertDictEqual(
+            {
+                'var0': 'val0',
+                'var2': 'val2',
+                '__versions':
+                {
+                    'var0': 1,
+                    'var2': 1
+                }
             },
             task2_2_ex.in_context
         )
@@ -1119,7 +1165,7 @@ class DirectWorkflowEngineTest(base.EngineTestCase):
             # versions of Python. On Python 3 this field's value was always
             # converted into a string no matter what we tried to assign. But
             # that didn't happen on Python 2.7 which caused an SQL exception.
-            self.assertIsInstance(task_ex.state_info, six.string_types)
+            self.assertIsInstance(task_ex.state_info, str)
 
     def test_single_fail_with_next_noop(self):
         wf_text = """---
@@ -1139,3 +1185,257 @@ class DirectWorkflowEngineTest(base.EngineTestCase):
         wf_ex = self.engine.start_workflow('wf')
 
         self.await_workflow_success(wf_ex.id)
+
+    def test_unexisting_join_task_does_not_stuck_wf_running(self):
+        wf_text = """---
+        version: '2.0'
+
+        wf:
+          tasks:
+            branch1:
+              action: std.noop
+              on-success: branch1-23_merge
+            branch2:
+              action: std.async_noop
+              on-success: branch2-3_merge
+            branch3:
+              action: std.fail
+              on-success: branch2-3_merge
+            branch2-3_merge:
+              action: std.noop
+              on-success: branch1-23_merge
+              join: all
+            branch1-23_merge:
+              action: std.noop
+              join: all
+        """
+
+        wf_service.create_workflows(wf_text)
+
+        # Start workflow.
+        wf_ex = self.engine.start_workflow('wf')
+
+        with db_api.transaction():
+            wf_ex = db_api.get_workflow_execution(wf_ex.id)
+
+            task_execs = wf_ex.task_executions
+
+        t_ex = self._assert_single_item(
+            task_execs,
+            name='branch2'
+        )
+        self.engine.start_task(t_ex.id, True, False, None, False, False)
+
+        t_action_exs = db_api.get_action_executions(
+            task_execution_id=t_ex.id
+        )
+
+        self.engine.on_action_complete(
+            t_action_exs[0].id,
+            ml_actions.Result(error="Error!")
+        )
+
+        self.await_workflow_error(wf_ex.id)
+
+    def test_join_task_has_correct_incoming_context(self):
+        wf_text = """---
+        version: '2.0'
+
+        wf:
+          tasks:
+            b1:
+              action: std.noop
+              publish:
+                b1: 1
+              on-success: join_task
+            join_task:
+              action: std.noop
+              join: all
+              publish:
+                join_task: 2
+              publish-on-error:
+                join_task: 1
+            bs:
+              action: std.noop
+              publish:
+                bs: 1
+              on-success:
+                - b2
+                - b3
+            b2:
+              action: std.noop
+              publish:
+                b2: 1
+              on-success: join_task
+            b3:
+              action: std.fail
+              publish-on-error:
+                b3: 1
+              on-success: join_task
+        """
+
+        wf_service.create_workflows(wf_text)
+
+        # Start workflow.
+        wf_ex = self.engine.start_workflow('wf')
+
+        self.await_workflow_error(wf_ex.id)
+
+        with db_api.transaction():
+            wf_ex = db_api.get_workflow_execution(wf_ex.id)
+
+            task_execs = wf_ex.task_executions
+            output = wf_ex.output
+
+        self.assertEqual(5, len(task_execs))
+
+        expected_context = {
+            "bs": 1,
+            "b3": 1,
+            "b1": 1,
+            "b2": 1,
+            "join_task": 1
+        }
+
+        self.assertDictContainsSubset(expected_context, output)
+
+    def test_context_versioning(self):
+        wf_text = """---
+        version: '2.0'
+
+        wf:
+          type: direct
+          output:
+            a: <% $.a %>
+            b: <% $.b %>
+
+          tasks:
+            task_start:
+              action: std.noop
+              publish:
+                a: 0
+                b: 0
+              on-success:
+                - task1_left
+                - task1_right
+
+            task1_left:
+              action: std.noop
+              publish:
+                a: 1
+              on-success: task2_left
+
+            task1_right:
+              action: std.noop
+              publish:
+                b: 1
+              on-success: task2_right
+
+            task2_left:
+              action: std.noop
+              on-success: task_final
+
+            task2_right:
+              action: std.noop
+              on-success: task_final
+
+            task_final:
+              action: std.noop
+              join: all
+
+        """
+
+        wf_service.create_workflows(wf_text)
+
+        # Start workflow.
+        wf_ex = self.engine.start_workflow('wf')
+
+        self.await_workflow_success(wf_ex.id)
+
+        with db_api.transaction():
+            # Note: We need to reread execution to access related tasks.
+            wf_ex = db_api.get_workflow_execution(wf_ex.id)
+
+            tasks = wf_ex.task_executions
+
+            wf_output = wf_ex.output
+
+        self.assertEqual(states.SUCCESS, wf_ex.state)
+
+        task_start = self._assert_single_item(tasks, name='task_start')
+        task1_left = self._assert_single_item(tasks, name='task1_left')
+        task1_right = self._assert_single_item(tasks, name='task1_right')
+        task2_left = self._assert_single_item(tasks, name='task2_left')
+        task2_right = self._assert_single_item(tasks, name='task2_right')
+        task_final = self._assert_single_item(tasks, name='task_final')
+
+        self.assertDictEqual({'a': 0, 'b': 0}, task_start.published)
+
+        self.assertDictEqual(
+            {
+                'a': 0,
+                'b': 0,
+                '__versions':
+                {
+                    'a': 1,
+                    'b': 1
+                }
+            },
+            task1_left.in_context
+        )
+        self.assertDictEqual({'a': 1}, task1_left.published)
+
+        self.assertDictEqual(
+            {
+                'a': 0,
+                'b': 0,
+                '__versions':
+                {
+                    'a': 1,
+                    'b': 1
+                }
+            },
+            task1_right.in_context
+        )
+        self.assertDictEqual({'b': 1}, task1_right.published)
+
+        self.assertDictEqual(
+            {
+                'a': 1,
+                'b': 0,
+                '__versions':
+                {
+                    'a': 2,
+                    'b': 1
+                }
+            },
+            task2_left.in_context
+        )
+
+        self.assertDictEqual(
+            {
+                'a': 0,
+                'b': 1,
+                '__versions':
+                {
+                    'a': 1,
+                    'b': 2
+                }
+            },
+            task2_right.in_context
+        )
+
+        self.assertDictEqual(
+            {
+                'a': 1,
+                'b': 1,
+                '__versions':
+                {
+                    'a': 2,
+                    'b': 2
+                }
+            },
+            task_final.in_context
+        )
+
+        self.assertDictEqual({'a': 1, 'b': 1}, wf_output)
