@@ -323,46 +323,3 @@ class ReverseWorkflowRerunTest(base.EngineTestCase):
             {'output': updated_env['var2']},
             task_3_action_exs[0].input
         )
-
-    @mock.patch.object(
-        std_actions.EchoAction,
-        'run',
-        mock.MagicMock(
-            side_effect=[
-                'Task 1',               # Mock task1 success for initial run.
-                exc.ActionException()   # Mock task2 exception for initial run.
-            ]
-        )
-    )
-    def test_rerun_from_prev_step(self):
-        wb_service.create_workbook_v2(SIMPLE_WORKBOOK)
-
-        # Run workflow and fail task.
-        wf_ex = self.engine.start_workflow('wb1.wf1', task_name='t3')
-
-        self.await_workflow_error(wf_ex.id)
-
-        with db_api.transaction():
-            wf_ex = db_api.get_workflow_execution(wf_ex.id)
-
-            task_execs = wf_ex.task_executions
-
-        self.assertEqual(states.ERROR, wf_ex.state)
-        self.assertIsNotNone(wf_ex.state_info)
-        self.assertEqual(2, len(task_execs))
-
-        task_1_ex = self._assert_single_item(task_execs, name='t1')
-        task_2_ex = self._assert_single_item(task_execs, name='t2')
-
-        self.assertEqual(states.SUCCESS, task_1_ex.state)
-        self.assertEqual(states.ERROR, task_2_ex.state)
-        self.assertIsNotNone(task_2_ex.state_info)
-
-        # Resume workflow and re-run failed task.
-        e = self.assertRaises(
-            exc.MistralError,
-            self.engine.rerun_workflow,
-            task_1_ex.id
-        )
-
-        self.assertIn('not supported', str(e))
